@@ -16,6 +16,7 @@ def evaluate_model(
         prompt: str,
         sample_size: int = SAMPLE_SIZE,
         output_dir: Path = Path('./samples'),
+        use_context_image: bool = False,
         infer_kwargs: Dict = {}
     ):
 
@@ -55,7 +56,11 @@ def evaluate_model(
 
         console.log(f'eval {sample.sample_id}...')
 
-        img = sample.get_image()
+        if use_context_image:
+            img = sample.get_context_image()
+        else:
+            img = sample.get_image()
+
         time_start = time.time()
 
         output = llm.infer(
